# Print an optspec for argparse to handle cmd's options that are independent of any subcommand.
function __fish_bcachefs_global_optspecs
	string join \n h/help
end

function __fish_bcachefs_needs_command
	# Figure out if the current invocation already has a command.
	set -l cmd (commandline -opc)
	set -e cmd[1]
	argparse -s (__fish_bcachefs_global_optspecs) -- $cmd 2>/dev/null
	or return
	if set -q argv[1]
		# Also print the command, so this can be used to figure out what it is.
		echo $argv[1]
		return 1
	end
	return 0
end

function __fish_bcachefs_using_subcommand
	set -l cmd (__fish_bcachefs_needs_command)
	test -z "$cmd"
	and return 1
	contains -- $cmd[1] $argv
end

complete -c bcachefs -n "__fish_bcachefs_needs_command" -s h -l help -d 'Print help'
complete -c bcachefs -n "__fish_bcachefs_needs_command" -f -a "format" -d 'Format a new filesystem'
complete -c bcachefs -n "__fish_bcachefs_needs_command" -f -a "show-super" -d 'Print superblock information'
complete -c bcachefs -n "__fish_bcachefs_needs_command" -f -a "recover-super" -d 'Recover damaged superblock'
complete -c bcachefs -n "__fish_bcachefs_needs_command" -f -a "set-fs-option" -d 'Set filesystem options'
complete -c bcachefs -n "__fish_bcachefs_needs_command" -f -a "reset-counters" -d 'Reset filesystem counters'
complete -c bcachefs -n "__fish_bcachefs_needs_command" -f -a "strip-alloc" -d 'Strip alloc info for read-only use'
complete -c bcachefs -n "__fish_bcachefs_needs_command" -f -a "image" -d 'Filesystem image commands'
complete -c bcachefs -n "__fish_bcachefs_needs_command" -f -a "mount" -d 'Mount a filesystem'
complete -c bcachefs -n "__fish_bcachefs_needs_command" -f -a "fusemount" -d 'FUSE mount'
complete -c bcachefs -n "__fish_bcachefs_needs_command" -f -a "wait-devices" -d 'Wait until every device in a filesystem is initialized'
complete -c bcachefs -n "__fish_bcachefs_needs_command" -f -a "fsck" -d 'Check filesystem consistency'
complete -c bcachefs -n "__fish_bcachefs_needs_command" -f -a "recovery-pass" -d 'Manage recovery passes'
complete -c bcachefs -n "__fish_bcachefs_needs_command" -f -a "fs" -d 'Manage a running filesystem'
complete -c bcachefs -n "__fish_bcachefs_needs_command" -f -a "device" -d 'Manage devices within a filesystem'
complete -c bcachefs -n "__fish_bcachefs_needs_command" -f -a "subvolume" -d 'Manage subvolumes and snapshots'
complete -c bcachefs -n "__fish_bcachefs_needs_command" -f -a "reconcile" -d 'Reconcile filesystem data'
complete -c bcachefs -n "__fish_bcachefs_needs_command" -f -a "scrub" -d 'Verify data checksums'
complete -c bcachefs -n "__fish_bcachefs_needs_command" -f -a "unlock" -d 'Unlock an encrypted filesystem'
complete -c bcachefs -n "__fish_bcachefs_needs_command" -f -a "set-passphrase" -d 'Set or change passphrase'
complete -c bcachefs -n "__fish_bcachefs_needs_command" -f -a "remove-passphrase" -d 'Remove passphrase'
complete -c bcachefs -n "__fish_bcachefs_needs_command" -f -a "migrate" -d 'Migrate existing filesystem to bcachefs'
complete -c bcachefs -n "__fish_bcachefs_needs_command" -f -a "migrate-superblock" -d 'Move superblock to standard location'
complete -c bcachefs -n "__fish_bcachefs_needs_command" -f -a "set-file-option" -d 'Set file-level options'
complete -c bcachefs -n "__fish_bcachefs_needs_command" -f -a "reflink-option-propagate" -d 'Propagate options to reflinked files'
complete -c bcachefs -n "__fish_bcachefs_needs_command" -f -a "dump" -d 'Dump filesystem metadata'
complete -c bcachefs -n "__fish_bcachefs_needs_command" -f -a "undump" -d 'Restore dumped metadata'
complete -c bcachefs -n "__fish_bcachefs_needs_command" -f -a "list" -d 'List filesystem metadata'
complete -c bcachefs -n "__fish_bcachefs_needs_command" -f -a "list_journal" -d 'List journal entries'
complete -c bcachefs -n "__fish_bcachefs_needs_command" -f -a "kill_btree_node" -d 'Remove a btree node'
complete -c bcachefs -n "__fish_bcachefs_needs_command" -f -a "data-read" -d 'Read data with extended error info'
complete -c bcachefs -n "__fish_bcachefs_needs_command" -f -a "unpoison" -d 'Clear poison flags on file extents'
complete -c bcachefs -n "__fish_bcachefs_needs_command" -f -a "completions" -d 'Generate shell completions'
complete -c bcachefs -n "__fish_bcachefs_needs_command" -f -a "version" -d 'Display version'
complete -c bcachefs -n "__fish_bcachefs_needs_command" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c bcachefs -n "__fish_bcachefs_using_subcommand format" -s h -l help -d 'Print help'
complete -c bcachefs -n "__fish_bcachefs_using_subcommand show-super" -s f -l fields -d 'Superblock fields to print (comma-separated, or "all")' -r
complete -c bcachefs -n "__fish_bcachefs_using_subcommand show-super" -s F -l field-only -d 'Print a single superblock field only (no header)' -r
complete -c bcachefs -n "__fish_bcachefs_using_subcommand show-super" -l help -d 'Print help'
complete -c bcachefs -n "__fish_bcachefs_using_subcommand show-super" -s l -l layout -d 'Print superblock layout'
complete -c bcachefs -n "__fish_bcachefs_using_subcommand recover-super" -s d -l dev_size -d 'Size of filesystem on device, in bytes' -r
complete -c bcachefs -n "__fish_bcachefs_using_subcommand recover-super" -s o -l offset -d 'Offset to probe, in bytes (must be a multiple of 512)' -r
complete -c bcachefs -n "__fish_bcachefs_using_subcommand recover-super" -s l -l scan_len -d 'Length in bytes to scan from start and end of device' -r
complete -c bcachefs -n "__fish_bcachefs_using_subcommand recover-super" -s s -l src_device -d 'Member device to recover from, in a multi-device fs' -r
complete -c bcachefs -n "__fish_bcachefs_using_subcommand recover-super" -s i -l dev_idx -d 'Index of this device, if recovering from another device' -r
complete -c bcachefs -n "__fish_bcachefs_using_subcommand recover-super" -s y -l yes -d 'Recover without prompting'
complete -c bcachefs -n "__fish_bcachefs_using_subcommand recover-super" -s v -l verbose -d 'Increase logging level'
complete -c bcachefs -n "__fish_bcachefs_using_subcommand recover-super" -s h -l help -d 'Print help'
complete -c bcachefs -n "__fish_bcachefs_using_subcommand set-fs-option" -s h -l help -d 'Print help'
complete -c bcachefs -n "__fish_bcachefs_using_subcommand reset-counters" -s c -l counters -l counter -d 'Reset specific counters (comma-separated), not all' -r
complete -c bcachefs -n "__fish_bcachefs_using_subcommand reset-counters" -s h -l help -d 'Print help'
complete -c bcachefs -n "__fish_bcachefs_using_subcommand strip-alloc" -s h -l help -d 'Print help'
complete -c bcachefs -n "__fish_bcachefs_using_subcommand image; and not __fish_seen_subcommand_from create update help" -s h -l help -d 'Print help'
complete -c bcachefs -n "__fish_bcachefs_using_subcommand image; and not __fish_seen_subcommand_from create update help" -f -a "create" -d 'Create a filesystem image'
complete -c bcachefs -n "__fish_bcachefs_using_subcommand image; and not __fish_seen_subcommand_from create update help" -f -a "update" -d 'Update a filesystem image'
complete -c bcachefs -n "__fish_bcachefs_using_subcommand image; and not __fish_seen_subcommand_from create update help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c bcachefs -n "__fish_bcachefs_using_subcommand image; and __fish_seen_subcommand_from create" -s h -l help -d 'Print help'
complete -c bcachefs -n "__fish_bcachefs_using_subcommand image; and __fish_seen_subcommand_from update" -s s -l source -d 'Source directory' -r
complete -c bcachefs -n "__fish_bcachefs_using_subcommand image; and __fish_seen_subcommand_from update" -s a -l keep-alloc -d 'Include allocation info in the filesystem'
complete -c bcachefs -n "__fish_bcachefs_using_subcommand image; and __fish_seen_subcommand_from update" -s q -l quiet -d 'Only print errors'
complete -c bcachefs -n "__fish_bcachefs_using_subcommand image; and __fish_seen_subcommand_from update" -s v -l verbose -d 'Verbose filesystem initialization'
complete -c bcachefs -n "__fish_bcachefs_using_subcommand image; and __fish_seen_subcommand_from update" -s h -l help -d 'Print help'
complete -c bcachefs -n "__fish_bcachefs_using_subcommand image; and __fish_seen_subcommand_from help" -f -a "create" -d 'Create a filesystem image'
complete -c bcachefs -n "__fish_bcachefs_using_subcommand image; and __fish_seen_subcommand_from help" -f -a "update" -d 'Update a filesystem image'
complete -c bcachefs -n "__fish_bcachefs_using_subcommand image; and __fish_seen_subcommand_from help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c bcachefs -n "__fish_bcachefs_using_subcommand mount" -s f -l passphrase-file -d 'Path to passphrase file' -r -F
complete -c bcachefs -n "__fish_bcachefs_using_subcommand mount" -s k -l key_location -d 'Passphrase policy to use in case of an encrypted filesystem. If not specified, the password will be searched for in the keyring. If not found, the password will be prompted or read from stdin, depending on whether the stdin is connected to a terminal or not' -r -f -a "{fail\t'Don\'t ask for passphrase, if the key cannot be found in the keyring just fail',wait\t'Wait for passphrase to become available before mounting',ask\t'Interactively prompt the user for a passphrase',stdin\t'Try to read the passphrase from `stdin` without prompting'}"
complete -c bcachefs -n "__fish_bcachefs_using_subcommand mount" -s o -d 'Mount options' -r
complete -c bcachefs -n "__fish_bcachefs_using_subcommand mount" -s t -l type -r
complete -c bcachefs -n "__fish_bcachefs_using_subcommand mount" -s c -l colorize -d 'Force color on/off. Autodetect tty is used to define default:' -r -f -a "{true\t'',false\t''}"
complete -c bcachefs -n "__fish_bcachefs_using_subcommand mount" -s v -l verbose -d 'Verbose mode'
complete -c bcachefs -n "__fish_bcachefs_using_subcommand mount" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c bcachefs -n "__fish_bcachefs_using_subcommand mount" -s V -l version -d 'Print version'
complete -c bcachefs -n "__fish_bcachefs_using_subcommand fusemount" -s o -d 'Mount options (-o key=value,...)' -r
complete -c bcachefs -n "__fish_bcachefs_using_subcommand fusemount" -s f -d 'Run in foreground'
complete -c bcachefs -n "__fish_bcachefs_using_subcommand fusemount" -s h -l help -d 'Print help'
complete -c bcachefs -n "__fish_bcachefs_using_subcommand wait-devices" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c bcachefs -n "__fish_bcachefs_using_subcommand fsck" -s o -d 'Additional mount options' -r
complete -c bcachefs -n "__fish_bcachefs_using_subcommand fsck" -s p -d 'Automatic repair (no questions)'
complete -c bcachefs -n "__fish_bcachefs_using_subcommand fsck" -s n -d 'Don\'t repair, only check for errors'
complete -c bcachefs -n "__fish_bcachefs_using_subcommand fsck" -s y -d 'Assume "yes" to all questions'
complete -c bcachefs -n "__fish_bcachefs_using_subcommand fsck" -s f -d 'Force checking even if filesystem is marked clean'
complete -c bcachefs -n "__fish_bcachefs_using_subcommand fsck" -s r -l ratelimit_errors -d 'Don\'t display more than 10 errors of a given type'
complete -c bcachefs -n "__fish_bcachefs_using_subcommand fsck" -s k -l kernel -d 'Use the in-kernel fsck implementation'
complete -c bcachefs -n "__fish_bcachefs_using_subcommand fsck" -s K -l no-kernel -d 'Don\'t use the in-kernel fsck implementation'
complete -c bcachefs -n "__fish_bcachefs_using_subcommand fsck" -s v -d 'Be verbose'
complete -c bcachefs -n "__fish_bcachefs_using_subcommand fsck" -s h -l help -d 'Print help'
complete -c bcachefs -n "__fish_bcachefs_using_subcommand recovery-pass" -s s -l set -d 'Schedule a recovery pass' -r
complete -c bcachefs -n "__fish_bcachefs_using_subcommand recovery-pass" -s u -l unset -d 'Deschedule a recovery pass' -r
complete -c bcachefs -n "__fish_bcachefs_using_subcommand recovery-pass" -s h -l help -d 'Print help'
complete -c bcachefs -n "__fish_bcachefs_using_subcommand fs; and not __fish_seen_subcommand_from usage top timestats help" -s h -l help -d 'Print help'
complete -c bcachefs -n "__fish_bcachefs_using_subcommand fs; and not __fish_seen_subcommand_from usage top timestats help" -f -a "usage" -d 'Show filesystem disk usage'
complete -c bcachefs -n "__fish_bcachefs_using_subcommand fs; and not __fish_seen_subcommand_from usage top timestats help" -f -a "top" -d 'Show live performance counters'
complete -c bcachefs -n "__fish_bcachefs_using_subcommand fs; and not __fish_seen_subcommand_from usage top timestats help" -f -a "timestats" -d 'Show operation latency statistics'
complete -c bcachefs -n "__fish_bcachefs_using_subcommand fs; and not __fish_seen_subcommand_from usage top timestats help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c bcachefs -n "__fish_bcachefs_using_subcommand fs; and __fish_seen_subcommand_from usage" -s f -l fields -d 'Comma-separated list of fields' -r -f -a "{replicas\t'',btree\t'',compression\t'',rebalance_work\t'',devices\t''}"
complete -c bcachefs -n "__fish_bcachefs_using_subcommand fs; and __fish_seen_subcommand_from usage" -l help -d 'Print help'
complete -c bcachefs -n "__fish_bcachefs_using_subcommand fs; and __fish_seen_subcommand_from usage" -s a -l all -d 'Print all accounting fields'
complete -c bcachefs -n "__fish_bcachefs_using_subcommand fs; and __fish_seen_subcommand_from usage" -s h -l human-readable -d 'Human-readable units'
complete -c bcachefs -n "__fish_bcachefs_using_subcommand fs; and __fish_seen_subcommand_from top" -s n -l count -d 'Number of samples to print, then exit (0 = unlimited / interactive TUI)' -r
complete -c bcachefs -n "__fish_bcachefs_using_subcommand fs; and __fish_seen_subcommand_from top" -s d -l delay -d 'Delay between samples, in seconds' -r
complete -c bcachefs -n "__fish_bcachefs_using_subcommand fs; and __fish_seen_subcommand_from top" -l help -d 'Print help'
complete -c bcachefs -n "__fish_bcachefs_using_subcommand fs; and __fish_seen_subcommand_from top" -s h -l human-readable -d 'Human-readable units'
complete -c bcachefs -n "__fish_bcachefs_using_subcommand fs; and __fish_seen_subcommand_from top" -l once -d 'One-shot output (no interactive TUI; equivalent to -n 1)'
complete -c bcachefs -n "__fish_bcachefs_using_subcommand fs; and __fish_seen_subcommand_from timestats" -s s -l sort -d 'Sort by column' -r -f -a "{name\t'',count\t'',dur-min\t'',dur-max\t'',dur-total\t'',mean-since\t'',mean-recent\t'',stddev-since\t'',stddev-recent\t''}"
complete -c bcachefs -n "__fish_bcachefs_using_subcommand fs; and __fish_seen_subcommand_from timestats" -s i -l interval -d 'Refresh interval in seconds (interactive mode)' -r
complete -c bcachefs -n "__fish_bcachefs_using_subcommand fs; and __fish_seen_subcommand_from timestats" -s a -l all -d 'Show stats with zero count'
complete -c bcachefs -n "__fish_bcachefs_using_subcommand fs; and __fish_seen_subcommand_from timestats" -l json -d 'Output raw JSON'
complete -c bcachefs -n "__fish_bcachefs_using_subcommand fs; and __fish_seen_subcommand_from timestats" -l no-device-stats -d 'Skip per-device IO latency stats'
complete -c bcachefs -n "__fish_bcachefs_using_subcommand fs; and __fish_seen_subcommand_from timestats" -l once -d 'One-shot output (no interactive TUI)'
complete -c bcachefs -n "__fish_bcachefs_using_subcommand fs; and __fish_seen_subcommand_from timestats" -s h -l help -d 'Print help'
complete -c bcachefs -n "__fish_bcachefs_using_subcommand fs; and __fish_seen_subcommand_from help" -f -a "usage" -d 'Show filesystem disk usage'
complete -c bcachefs -n "__fish_bcachefs_using_subcommand fs; and __fish_seen_subcommand_from help" -f -a "top" -d 'Show live performance counters'
complete -c bcachefs -n "__fish_bcachefs_using_subcommand fs; and __fish_seen_subcommand_from help" -f -a "timestats" -d 'Show operation latency statistics'
complete -c bcachefs -n "__fish_bcachefs_using_subcommand fs; and __fish_seen_subcommand_from help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c bcachefs -n "__fish_bcachefs_using_subcommand device; and not __fish_seen_subcommand_from add online offline remove evacuate set-state resize resize-journal help" -s h -l help -d 'Print help'
complete -c bcachefs -n "__fish_bcachefs_using_subcommand device; and not __fish_seen_subcommand_from add online offline remove evacuate set-state resize resize-journal help" -f -a "add" -d 'Add a device to a filesystem'
complete -c bcachefs -n "__fish_bcachefs_using_subcommand device; and not __fish_seen_subcommand_from add online offline remove evacuate set-state resize resize-journal help" -f -a "online" -d 'Bring a device online'
complete -c bcachefs -n "__fish_bcachefs_using_subcommand device; and not __fish_seen_subcommand_from add online offline remove evacuate set-state resize resize-journal help" -f -a "offline" -d 'Take a device offline'
complete -c bcachefs -n "__fish_bcachefs_using_subcommand device; and not __fish_seen_subcommand_from add online offline remove evacuate set-state resize resize-journal help" -f -a "remove" -d 'Remove a device'
complete -c bcachefs -n "__fish_bcachefs_using_subcommand device; and not __fish_seen_subcommand_from add online offline remove evacuate set-state resize resize-journal help" -f -a "evacuate" -d 'Evacuate data from a device'
complete -c bcachefs -n "__fish_bcachefs_using_subcommand device; and not __fish_seen_subcommand_from add online offline remove evacuate set-state resize resize-journal help" -f -a "set-state" -d 'Set device state'
complete -c bcachefs -n "__fish_bcachefs_using_subcommand device; and not __fish_seen_subcommand_from add online offline remove evacuate set-state resize resize-journal help" -f -a "resize" -d 'Resize filesystem on a device'
complete -c bcachefs -n "__fish_bcachefs_using_subcommand device; and not __fish_seen_subcommand_from add online offline remove evacuate set-state resize resize-journal help" -f -a "resize-journal" -d 'Resize journal on a device'
complete -c bcachefs -n "__fish_bcachefs_using_subcommand device; and not __fish_seen_subcommand_from add online offline remove evacuate set-state resize resize-journal help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c bcachefs -n "__fish_bcachefs_using_subcommand device; and __fish_seen_subcommand_from add" -s h -l help -d 'Print help'
complete -c bcachefs -n "__fish_bcachefs_using_subcommand device; and __fish_seen_subcommand_from online" -s h -l help -d 'Print help'
complete -c bcachefs -n "__fish_bcachefs_using_subcommand device; and __fish_seen_subcommand_from offline" -s f -l force -d 'Force, if data redundancy will be degraded'
complete -c bcachefs -n "__fish_bcachefs_using_subcommand device; and __fish_seen_subcommand_from offline" -s h -l help -d 'Print help'
complete -c bcachefs -n "__fish_bcachefs_using_subcommand device; and __fish_seen_subcommand_from remove" -s f -l force -d 'Force removal, even if some data couldn\'t be migrated'
complete -c bcachefs -n "__fish_bcachefs_using_subcommand device; and __fish_seen_subcommand_from remove" -s F -l force-metadata -d 'Force removal, even if some metadata couldn\'t be migrated'
complete -c bcachefs -n "__fish_bcachefs_using_subcommand device; and __fish_seen_subcommand_from remove" -s h -l help -d 'Print help'
complete -c bcachefs -n "__fish_bcachefs_using_subcommand device; and __fish_seen_subcommand_from evacuate" -s h -l help -d 'Print help'
complete -c bcachefs -n "__fish_bcachefs_using_subcommand device; and __fish_seen_subcommand_from set-state" -s f -l force -d 'Force if data redundancy will be degraded'
complete -c bcachefs -n "__fish_bcachefs_using_subcommand device; and __fish_seen_subcommand_from set-state" -s F -l force-if-data-lost -d 'Force even if data will be lost'
complete -c bcachefs -n "__fish_bcachefs_using_subcommand device; and __fish_seen_subcommand_from set-state" -s o -l offline -d 'Set state of an offline device'
complete -c bcachefs -n "__fish_bcachefs_using_subcommand device; and __fish_seen_subcommand_from set-state" -s h -l help -d 'Print help'
complete -c bcachefs -n "__fish_bcachefs_using_subcommand device; and __fish_seen_subcommand_from resize" -s h -l help -d 'Print help'
complete -c bcachefs -n "__fish_bcachefs_using_subcommand device; and __fish_seen_subcommand_from resize-journal" -s h -l help -d 'Print help'
complete -c bcachefs -n "__fish_bcachefs_using_subcommand device; and __fish_seen_subcommand_from help" -f -a "add" -d 'Add a device to a filesystem'
complete -c bcachefs -n "__fish_bcachefs_using_subcommand device; and __fish_seen_subcommand_from help" -f -a "online" -d 'Bring a device online'
complete -c bcachefs -n "__fish_bcachefs_using_subcommand device; and __fish_seen_subcommand_from help" -f -a "offline" -d 'Take a device offline'
complete -c bcachefs -n "__fish_bcachefs_using_subcommand device; and __fish_seen_subcommand_from help" -f -a "remove" -d 'Remove a device'
complete -c bcachefs -n "__fish_bcachefs_using_subcommand device; and __fish_seen_subcommand_from help" -f -a "evacuate" -d 'Evacuate data from a device'
complete -c bcachefs -n "__fish_bcachefs_using_subcommand device; and __fish_seen_subcommand_from help" -f -a "set-state" -d 'Set device state'
complete -c bcachefs -n "__fish_bcachefs_using_subcommand device; and __fish_seen_subcommand_from help" -f -a "resize" -d 'Resize filesystem on a device'
complete -c bcachefs -n "__fish_bcachefs_using_subcommand device; and __fish_seen_subcommand_from help" -f -a "resize-journal" -d 'Resize journal on a device'
complete -c bcachefs -n "__fish_bcachefs_using_subcommand device; and __fish_seen_subcommand_from help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c bcachefs -n "__fish_bcachefs_using_subcommand subvolume; and not __fish_seen_subcommand_from create new delete del snapshot snap list ls list-snapshots ls-snap list-snap help" -s h -l help -d 'Print help'
complete -c bcachefs -n "__fish_bcachefs_using_subcommand subvolume; and not __fish_seen_subcommand_from create new delete del snapshot snap list ls list-snapshots ls-snap list-snap help" -f -a "create" -d 'Create a new subvolume'
complete -c bcachefs -n "__fish_bcachefs_using_subcommand subvolume; and not __fish_seen_subcommand_from create new delete del snapshot snap list ls list-snapshots ls-snap list-snap help" -f -a "new" -d 'Create a new subvolume'
complete -c bcachefs -n "__fish_bcachefs_using_subcommand subvolume; and not __fish_seen_subcommand_from create new delete del snapshot snap list ls list-snapshots ls-snap list-snap help" -f -a "delete" -d 'Delete an existing subvolume'
complete -c bcachefs -n "__fish_bcachefs_using_subcommand subvolume; and not __fish_seen_subcommand_from create new delete del snapshot snap list ls list-snapshots ls-snap list-snap help" -f -a "del" -d 'Delete an existing subvolume'
complete -c bcachefs -n "__fish_bcachefs_using_subcommand subvolume; and not __fish_seen_subcommand_from create new delete del snapshot snap list ls list-snapshots ls-snap list-snap help" -f -a "snapshot" -d 'Create a snapshot of a subvolume'
complete -c bcachefs -n "__fish_bcachefs_using_subcommand subvolume; and not __fish_seen_subcommand_from create new delete del snapshot snap list ls list-snapshots ls-snap list-snap help" -f -a "snap" -d 'Create a snapshot of a subvolume'
complete -c bcachefs -n "__fish_bcachefs_using_subcommand subvolume; and not __fish_seen_subcommand_from create new delete del snapshot snap list ls list-snapshots ls-snap list-snap help" -f -a "list" -d 'List subvolumes'
complete -c bcachefs -n "__fish_bcachefs_using_subcommand subvolume; and not __fish_seen_subcommand_from create new delete del snapshot snap list ls list-snapshots ls-snap list-snap help" -f -a "ls" -d 'List subvolumes'
complete -c bcachefs -n "__fish_bcachefs_using_subcommand subvolume; and not __fish_seen_subcommand_from create new delete del snapshot snap list ls list-snapshots ls-snap list-snap help" -f -a "list-snapshots" -d 'List snapshots and their disk usage'
complete -c bcachefs -n "__fish_bcachefs_using_subcommand subvolume; and not __fish_seen_subcommand_from create new delete del snapshot snap list ls list-snapshots ls-snap list-snap help" -f -a "ls-snap" -d 'List snapshots and their disk usage'
complete -c bcachefs -n "__fish_bcachefs_using_subcommand subvolume; and not __fish_seen_subcommand_from create new delete del snapshot snap list ls list-snapshots ls-snap list-snap help" -f -a "list-snap" -d 'List snapshots and their disk usage'
complete -c bcachefs -n "__fish_bcachefs_using_subcommand subvolume; and not __fish_seen_subcommand_from create new delete del snapshot snap list ls list-snapshots ls-snap list-snap help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c bcachefs -n "__fish_bcachefs_using_subcommand subvolume; and __fish_seen_subcommand_from create" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c bcachefs -n "__fish_bcachefs_using_subcommand subvolume; and __fish_seen_subcommand_from new" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c bcachefs -n "__fish_bcachefs_using_subcommand subvolume; and __fish_seen_subcommand_from delete" -s h -l help -d 'Print help'
complete -c bcachefs -n "__fish_bcachefs_using_subcommand subvolume; and __fish_seen_subcommand_from del" -s h -l help -d 'Print help'
complete -c bcachefs -n "__fish_bcachefs_using_subcommand subvolume; and __fish_seen_subcommand_from snapshot" -s r -l read-only -d 'Make snapshot read only'
complete -c bcachefs -n "__fish_bcachefs_using_subcommand subvolume; and __fish_seen_subcommand_from snapshot" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c bcachefs -n "__fish_bcachefs_using_subcommand subvolume; and __fish_seen_subcommand_from snap" -s r -l read-only -d 'Make snapshot read only'
complete -c bcachefs -n "__fish_bcachefs_using_subcommand subvolume; and __fish_seen_subcommand_from snap" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c bcachefs -n "__fish_bcachefs_using_subcommand subvolume; and __fish_seen_subcommand_from list" -l sort -d 'Sort order' -r -f -a "{name\t'',size\t'',time\t''}"
complete -c bcachefs -n "__fish_bcachefs_using_subcommand subvolume; and __fish_seen_subcommand_from list" -l json -d 'Output as JSON'
complete -c bcachefs -n "__fish_bcachefs_using_subcommand subvolume; and __fish_seen_subcommand_from list" -s t -l tree -d 'Show subvolume tree structure (implies -R)'
complete -c bcachefs -n "__fish_bcachefs_using_subcommand subvolume; and __fish_seen_subcommand_from list" -s R -l recursive -d 'List subvolumes recursively'
complete -c bcachefs -n "__fish_bcachefs_using_subcommand subvolume; and __fish_seen_subcommand_from list" -s s -l snapshots -d 'Include snapshot subvolumes'
complete -c bcachefs -n "__fish_bcachefs_using_subcommand subvolume; and __fish_seen_subcommand_from list" -l readonly -d 'Only show read-only subvolumes'
complete -c bcachefs -n "__fish_bcachefs_using_subcommand subvolume; and __fish_seen_subcommand_from list" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c bcachefs -n "__fish_bcachefs_using_subcommand subvolume; and __fish_seen_subcommand_from ls" -l sort -d 'Sort order' -r -f -a "{name\t'',size\t'',time\t''}"
complete -c bcachefs -n "__fish_bcachefs_using_subcommand subvolume; and __fish_seen_subcommand_from ls" -l json -d 'Output as JSON'
complete -c bcachefs -n "__fish_bcachefs_using_subcommand subvolume; and __fish_seen_subcommand_from ls" -s t -l tree -d 'Show subvolume tree structure (implies -R)'
complete -c bcachefs -n "__fish_bcachefs_using_subcommand subvolume; and __fish_seen_subcommand_from ls" -s R -l recursive -d 'List subvolumes recursively'
complete -c bcachefs -n "__fish_bcachefs_using_subcommand subvolume; and __fish_seen_subcommand_from ls" -s s -l snapshots -d 'Include snapshot subvolumes'
complete -c bcachefs -n "__fish_bcachefs_using_subcommand subvolume; and __fish_seen_subcommand_from ls" -l readonly -d 'Only show read-only subvolumes'
complete -c bcachefs -n "__fish_bcachefs_using_subcommand subvolume; and __fish_seen_subcommand_from ls" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c bcachefs -n "__fish_bcachefs_using_subcommand subvolume; and __fish_seen_subcommand_from list-snapshots" -l sort -d 'Sort order (flat view only)' -r -f -a "{name\t'',size\t'',time\t''}"
complete -c bcachefs -n "__fish_bcachefs_using_subcommand subvolume; and __fish_seen_subcommand_from list-snapshots" -s f -l flat -d 'Show flat list instead of tree'
complete -c bcachefs -n "__fish_bcachefs_using_subcommand subvolume; and __fish_seen_subcommand_from list-snapshots" -l json -d 'Output as JSON'
complete -c bcachefs -n "__fish_bcachefs_using_subcommand subvolume; and __fish_seen_subcommand_from list-snapshots" -l readonly -d 'Only show read-only snapshots (flat view only)'
complete -c bcachefs -n "__fish_bcachefs_using_subcommand subvolume; and __fish_seen_subcommand_from list-snapshots" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c bcachefs -n "__fish_bcachefs_using_subcommand subvolume; and __fish_seen_subcommand_from ls-snap" -l sort -d 'Sort order (flat view only)' -r -f -a "{name\t'',size\t'',time\t''}"
complete -c bcachefs -n "__fish_bcachefs_using_subcommand subvolume; and __fish_seen_subcommand_from ls-snap" -s f -l flat -d 'Show flat list instead of tree'
complete -c bcachefs -n "__fish_bcachefs_using_subcommand subvolume; and __fish_seen_subcommand_from ls-snap" -l json -d 'Output as JSON'
complete -c bcachefs -n "__fish_bcachefs_using_subcommand subvolume; and __fish_seen_subcommand_from ls-snap" -l readonly -d 'Only show read-only snapshots (flat view only)'
complete -c bcachefs -n "__fish_bcachefs_using_subcommand subvolume; and __fish_seen_subcommand_from ls-snap" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c bcachefs -n "__fish_bcachefs_using_subcommand subvolume; and __fish_seen_subcommand_from list-snap" -l sort -d 'Sort order (flat view only)' -r -f -a "{name\t'',size\t'',time\t''}"
complete -c bcachefs -n "__fish_bcachefs_using_subcommand subvolume; and __fish_seen_subcommand_from list-snap" -s f -l flat -d 'Show flat list instead of tree'
complete -c bcachefs -n "__fish_bcachefs_using_subcommand subvolume; and __fish_seen_subcommand_from list-snap" -l json -d 'Output as JSON'
complete -c bcachefs -n "__fish_bcachefs_using_subcommand subvolume; and __fish_seen_subcommand_from list-snap" -l readonly -d 'Only show read-only snapshots (flat view only)'
complete -c bcachefs -n "__fish_bcachefs_using_subcommand subvolume; and __fish_seen_subcommand_from list-snap" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c bcachefs -n "__fish_bcachefs_using_subcommand subvolume; and __fish_seen_subcommand_from help" -f -a "create" -d 'Create a new subvolume'
complete -c bcachefs -n "__fish_bcachefs_using_subcommand subvolume; and __fish_seen_subcommand_from help" -f -a "delete" -d 'Delete an existing subvolume'
complete -c bcachefs -n "__fish_bcachefs_using_subcommand subvolume; and __fish_seen_subcommand_from help" -f -a "snapshot" -d 'Create a snapshot of a subvolume'
complete -c bcachefs -n "__fish_bcachefs_using_subcommand subvolume; and __fish_seen_subcommand_from help" -f -a "list" -d 'List subvolumes'
complete -c bcachefs -n "__fish_bcachefs_using_subcommand subvolume; and __fish_seen_subcommand_from help" -f -a "list-snapshots" -d 'List snapshots and their disk usage'
complete -c bcachefs -n "__fish_bcachefs_using_subcommand subvolume; and __fish_seen_subcommand_from help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c bcachefs -n "__fish_bcachefs_using_subcommand reconcile; and not __fish_seen_subcommand_from status wait help" -s h -l help -d 'Print help'
complete -c bcachefs -n "__fish_bcachefs_using_subcommand reconcile; and not __fish_seen_subcommand_from status wait help" -f -a "status" -d 'Show reconcile status'
complete -c bcachefs -n "__fish_bcachefs_using_subcommand reconcile; and not __fish_seen_subcommand_from status wait help" -f -a "wait" -d 'Wait for reconcile to complete'
complete -c bcachefs -n "__fish_bcachefs_using_subcommand reconcile; and not __fish_seen_subcommand_from status wait help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c bcachefs -n "__fish_bcachefs_using_subcommand reconcile; and __fish_seen_subcommand_from status" -s t -l types -d 'Reconcile types to display (comma-separated)' -r -f -a "{replicas\t'',checksum\t'',erasure_code\t'',compression\t'',target\t'',high_priority\t'',pending\t'',stripes\t''}"
complete -c bcachefs -n "__fish_bcachefs_using_subcommand reconcile; and __fish_seen_subcommand_from status" -l help -d 'Print help'
complete -c bcachefs -n "__fish_bcachefs_using_subcommand reconcile; and __fish_seen_subcommand_from wait" -s t -l types -d 'Reconcile types to wait on (comma-separated)' -r -f -a "{replicas\t'',checksum\t'',erasure_code\t'',compression\t'',target\t'',high_priority\t'',pending\t'',stripes\t''}"
complete -c bcachefs -n "__fish_bcachefs_using_subcommand reconcile; and __fish_seen_subcommand_from wait" -l help -d 'Print help'
complete -c bcachefs -n "__fish_bcachefs_using_subcommand reconcile; and __fish_seen_subcommand_from help" -f -a "status" -d 'Show reconcile status'
complete -c bcachefs -n "__fish_bcachefs_using_subcommand reconcile; and __fish_seen_subcommand_from help" -f -a "wait" -d 'Wait for reconcile to complete'
complete -c bcachefs -n "__fish_bcachefs_using_subcommand reconcile; and __fish_seen_subcommand_from help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c bcachefs -n "__fish_bcachefs_using_subcommand scrub" -s m -l metadata -d 'Check metadata only'
complete -c bcachefs -n "__fish_bcachefs_using_subcommand scrub" -s h -l help -d 'Print help'
complete -c bcachefs -n "__fish_bcachefs_using_subcommand unlock" -s k -l keyring -d 'Keyring to add to' -r -f -a "{session\t'',user\t'',user_session\t''}"
complete -c bcachefs -n "__fish_bcachefs_using_subcommand unlock" -s f -l file -d 'Passphrase file to read from (disables passphrase prompt)' -r -F
complete -c bcachefs -n "__fish_bcachefs_using_subcommand unlock" -s c -l check -d 'Check if a device is encrypted'
complete -c bcachefs -n "__fish_bcachefs_using_subcommand unlock" -s h -l help -d 'Print help'
complete -c bcachefs -n "__fish_bcachefs_using_subcommand set-passphrase" -s h -l help -d 'Print help'
complete -c bcachefs -n "__fish_bcachefs_using_subcommand remove-passphrase" -s h -l help -d 'Print help'
complete -c bcachefs -n "__fish_bcachefs_using_subcommand migrate" -s h -l help -d 'Print help'
complete -c bcachefs -n "__fish_bcachefs_using_subcommand migrate-superblock" -s d -l dev -d 'Device to create superblock for' -r
complete -c bcachefs -n "__fish_bcachefs_using_subcommand migrate-superblock" -s o -l offset -d 'Offset of existing superblock' -r
complete -c bcachefs -n "__fish_bcachefs_using_subcommand migrate-superblock" -s h -l help -d 'Print help'
complete -c bcachefs -n "__fish_bcachefs_using_subcommand set-file-option" -s h -l help -d 'Print help'
complete -c bcachefs -n "__fish_bcachefs_using_subcommand reflink-option-propagate" -s h -l help -d 'Print help'
complete -c bcachefs -n "__fish_bcachefs_using_subcommand dump" -s o -d 'Output filename (without .qcow2 extension)' -r
complete -c bcachefs -n "__fish_bcachefs_using_subcommand dump" -s s -l sanitize -d 'Sanitize inline data and optionally filenames (data or filenames)' -r
complete -c bcachefs -n "__fish_bcachefs_using_subcommand dump" -s f -l force -d 'Force; overwrite existing files'
complete -c bcachefs -n "__fish_bcachefs_using_subcommand dump" -l nojournal -d 'Don\'t dump entire journal, just dirty entries'
complete -c bcachefs -n "__fish_bcachefs_using_subcommand dump" -l noexcl -d 'Open devices without O_EXCL'
complete -c bcachefs -n "__fish_bcachefs_using_subcommand dump" -s v -l verbose -d 'Verbose output'
complete -c bcachefs -n "__fish_bcachefs_using_subcommand dump" -s h -l help -d 'Print help'
complete -c bcachefs -n "__fish_bcachefs_using_subcommand undump" -s f -l force -d 'Overwrite existing output files'
complete -c bcachefs -n "__fish_bcachefs_using_subcommand undump" -s h -l help -d 'Print help'
complete -c bcachefs -n "__fish_bcachefs_using_subcommand list" -s m -l mode -r -f -a "{keys\t'',formats\t'',nodes\t'',nodes-ondisk\t''}"
complete -c bcachefs -n "__fish_bcachefs_using_subcommand list" -s b -l btree -d 'Btree to list from' -r
complete -c bcachefs -n "__fish_bcachefs_using_subcommand list" -s k -l bkey-type -d 'Bkey type to list' -r
complete -c bcachefs -n "__fish_bcachefs_using_subcommand list" -s l -l level -d 'Btree depth to descend to (0 == leaves)' -r
complete -c bcachefs -n "__fish_bcachefs_using_subcommand list" -s s -l start -d 'Start position to list from' -r
complete -c bcachefs -n "__fish_bcachefs_using_subcommand list" -s e -l end -d 'End position' -r
complete -c bcachefs -n "__fish_bcachefs_using_subcommand list" -s c -l colorize -d 'Force color on/off. Default: autodetect tty' -r -f -a "{true\t'',false\t''}"
complete -c bcachefs -n "__fish_bcachefs_using_subcommand list" -s f -l fsck -d 'Check (fsck) the filesystem first'
complete -c bcachefs -n "__fish_bcachefs_using_subcommand list" -s v -l verbose -d 'Verbose mode'
complete -c bcachefs -n "__fish_bcachefs_using_subcommand list" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c bcachefs -n "__fish_bcachefs_using_subcommand list_journal" -s n -l nr-entries -d 'Number of journal entries to print' -r
complete -c bcachefs -n "__fish_bcachefs_using_subcommand list_journal" -s s -l seq -d 'Sequence number or range (seq or seq..seq)' -r
complete -c bcachefs -n "__fish_bcachefs_using_subcommand list_journal" -s o -d 'Additional mount options' -r
complete -c bcachefs -n "__fish_bcachefs_using_subcommand list_journal" -s b -l btree -d 'Filter by btree (+/-btree1,btree2)' -r
complete -c bcachefs -n "__fish_bcachefs_using_subcommand list_journal" -s t -l transaction -d 'Filter transactions by function (+/-fn1,fn2)' -r
complete -c bcachefs -n "__fish_bcachefs_using_subcommand list_journal" -s k -l key -d 'Filter by key range (+/-bbpos[-bbpos],...)' -r
complete -c bcachefs -n "__fish_bcachefs_using_subcommand list_journal" -s V -l bkey-val -d 'Print bkey values (true/false)' -r
complete -c bcachefs -n "__fish_bcachefs_using_subcommand list_journal" -s a -l all -d 'Read entire journal, not just contiguous entries'
complete -c bcachefs -n "__fish_bcachefs_using_subcommand list_journal" -s d -l dirty-only -d 'Only read dirty entries'
complete -c bcachefs -n "__fish_bcachefs_using_subcommand list_journal" -s B -l blacklisted -d 'Include blacklisted entries'
complete -c bcachefs -n "__fish_bcachefs_using_subcommand list_journal" -s F -l flush-only -d 'Only flush entries'
complete -c bcachefs -n "__fish_bcachefs_using_subcommand list_journal" -s D -l datetime -d 'Datetime entries only'
complete -c bcachefs -n "__fish_bcachefs_using_subcommand list_journal" -s H -l headers-only -d 'Headers only'
complete -c bcachefs -n "__fish_bcachefs_using_subcommand list_journal" -l all-headers -d 'Print all headers even if no transactions matched'
complete -c bcachefs -n "__fish_bcachefs_using_subcommand list_journal" -s l -l log -d 'Include log-only entries when filtering'
complete -c bcachefs -n "__fish_bcachefs_using_subcommand list_journal" -s L -l log-only -d 'Only print transactions containing log messages'
complete -c bcachefs -n "__fish_bcachefs_using_subcommand list_journal" -s O -l offset -d 'Print offset of each subentry'
complete -c bcachefs -n "__fish_bcachefs_using_subcommand list_journal" -s v -l verbose -d 'Verbose mode'
complete -c bcachefs -n "__fish_bcachefs_using_subcommand list_journal" -s h -l help -d 'Print help'
complete -c bcachefs -n "__fish_bcachefs_using_subcommand kill_btree_node" -s n -l node -d 'Node to kill (btree:level:idx)' -r
complete -c bcachefs -n "__fish_bcachefs_using_subcommand kill_btree_node" -s d -l dev -d 'Device index (default: kill all replicas)' -r
complete -c bcachefs -n "__fish_bcachefs_using_subcommand kill_btree_node" -s h -l help -d 'Print help'
complete -c bcachefs -n "__fish_bcachefs_using_subcommand data-read" -l offset -d 'Offset in bytes (must be sector-aligned)' -r
complete -c bcachefs -n "__fish_bcachefs_using_subcommand data-read" -l len -d 'Length in bytes (must be sector-aligned, default: one page)' -r
complete -c bcachefs -n "__fish_bcachefs_using_subcommand data-read" -l output -d 'Write raw data to this file instead of hex dump' -r
complete -c bcachefs -n "__fish_bcachefs_using_subcommand data-read" -l width -d 'Hex dump width' -r
complete -c bcachefs -n "__fish_bcachefs_using_subcommand data-read" -l no-poison-check -d 'Bypass poison checks (read data even from poisoned extents)'
complete -c bcachefs -n "__fish_bcachefs_using_subcommand data-read" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c bcachefs -n "__fish_bcachefs_using_subcommand unpoison" -l offset -d 'Start offset in bytes (must be sector-aligned)' -r
complete -c bcachefs -n "__fish_bcachefs_using_subcommand unpoison" -l len -d 'Length in bytes (must be sector-aligned, 0 = entire file)' -r
complete -c bcachefs -n "__fish_bcachefs_using_subcommand unpoison" -l yes-i-understand -d 'Required to confirm you understand the risks'
complete -c bcachefs -n "__fish_bcachefs_using_subcommand unpoison" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c bcachefs -n "__fish_bcachefs_using_subcommand completions" -s h -l help -d 'Print help'
complete -c bcachefs -n "__fish_bcachefs_using_subcommand version" -s h -l help -d 'Print help'
complete -c bcachefs -n "__fish_bcachefs_using_subcommand help; and not __fish_seen_subcommand_from format show-super recover-super set-fs-option reset-counters strip-alloc image mount fusemount wait-devices fsck recovery-pass fs device subvolume reconcile scrub unlock set-passphrase remove-passphrase migrate migrate-superblock set-file-option reflink-option-propagate dump undump list list_journal kill_btree_node data-read unpoison completions version help" -f -a "format" -d 'Format a new filesystem'
complete -c bcachefs -n "__fish_bcachefs_using_subcommand help; and not __fish_seen_subcommand_from format show-super recover-super set-fs-option reset-counters strip-alloc image mount fusemount wait-devices fsck recovery-pass fs device subvolume reconcile scrub unlock set-passphrase remove-passphrase migrate migrate-superblock set-file-option reflink-option-propagate dump undump list list_journal kill_btree_node data-read unpoison completions version help" -f -a "show-super" -d 'Print superblock information'
complete -c bcachefs -n "__fish_bcachefs_using_subcommand help; and not __fish_seen_subcommand_from format show-super recover-super set-fs-option reset-counters strip-alloc image mount fusemount wait-devices fsck recovery-pass fs device subvolume reconcile scrub unlock set-passphrase remove-passphrase migrate migrate-superblock set-file-option reflink-option-propagate dump undump list list_journal kill_btree_node data-read unpoison completions version help" -f -a "recover-super" -d 'Recover damaged superblock'
complete -c bcachefs -n "__fish_bcachefs_using_subcommand help; and not __fish_seen_subcommand_from format show-super recover-super set-fs-option reset-counters strip-alloc image mount fusemount wait-devices fsck recovery-pass fs device subvolume reconcile scrub unlock set-passphrase remove-passphrase migrate migrate-superblock set-file-option reflink-option-propagate dump undump list list_journal kill_btree_node data-read unpoison completions version help" -f -a "set-fs-option" -d 'Set filesystem options'
complete -c bcachefs -n "__fish_bcachefs_using_subcommand help; and not __fish_seen_subcommand_from format show-super recover-super set-fs-option reset-counters strip-alloc image mount fusemount wait-devices fsck recovery-pass fs device subvolume reconcile scrub unlock set-passphrase remove-passphrase migrate migrate-superblock set-file-option reflink-option-propagate dump undump list list_journal kill_btree_node data-read unpoison completions version help" -f -a "reset-counters" -d 'Reset filesystem counters'
complete -c bcachefs -n "__fish_bcachefs_using_subcommand help; and not __fish_seen_subcommand_from format show-super recover-super set-fs-option reset-counters strip-alloc image mount fusemount wait-devices fsck recovery-pass fs device subvolume reconcile scrub unlock set-passphrase remove-passphrase migrate migrate-superblock set-file-option reflink-option-propagate dump undump list list_journal kill_btree_node data-read unpoison completions version help" -f -a "strip-alloc" -d 'Strip alloc info for read-only use'
complete -c bcachefs -n "__fish_bcachefs_using_subcommand help; and not __fish_seen_subcommand_from format show-super recover-super set-fs-option reset-counters strip-alloc image mount fusemount wait-devices fsck recovery-pass fs device subvolume reconcile scrub unlock set-passphrase remove-passphrase migrate migrate-superblock set-file-option reflink-option-propagate dump undump list list_journal kill_btree_node data-read unpoison completions version help" -f -a "image" -d 'Filesystem image commands'
complete -c bcachefs -n "__fish_bcachefs_using_subcommand help; and not __fish_seen_subcommand_from format show-super recover-super set-fs-option reset-counters strip-alloc image mount fusemount wait-devices fsck recovery-pass fs device subvolume reconcile scrub unlock set-passphrase remove-passphrase migrate migrate-superblock set-file-option reflink-option-propagate dump undump list list_journal kill_btree_node data-read unpoison completions version help" -f -a "mount" -d 'Mount a filesystem'
complete -c bcachefs -n "__fish_bcachefs_using_subcommand help; and not __fish_seen_subcommand_from format show-super recover-super set-fs-option reset-counters strip-alloc image mount fusemount wait-devices fsck recovery-pass fs device subvolume reconcile scrub unlock set-passphrase remove-passphrase migrate migrate-superblock set-file-option reflink-option-propagate dump undump list list_journal kill_btree_node data-read unpoison completions version help" -f -a "fusemount" -d 'FUSE mount'
complete -c bcachefs -n "__fish_bcachefs_using_subcommand help; and not __fish_seen_subcommand_from format show-super recover-super set-fs-option reset-counters strip-alloc image mount fusemount wait-devices fsck recovery-pass fs device subvolume reconcile scrub unlock set-passphrase remove-passphrase migrate migrate-superblock set-file-option reflink-option-propagate dump undump list list_journal kill_btree_node data-read unpoison completions version help" -f -a "wait-devices" -d 'Wait until every device in a filesystem is initialized'
complete -c bcachefs -n "__fish_bcachefs_using_subcommand help; and not __fish_seen_subcommand_from format show-super recover-super set-fs-option reset-counters strip-alloc image mount fusemount wait-devices fsck recovery-pass fs device subvolume reconcile scrub unlock set-passphrase remove-passphrase migrate migrate-superblock set-file-option reflink-option-propagate dump undump list list_journal kill_btree_node data-read unpoison completions version help" -f -a "fsck" -d 'Check filesystem consistency'
complete -c bcachefs -n "__fish_bcachefs_using_subcommand help; and not __fish_seen_subcommand_from format show-super recover-super set-fs-option reset-counters strip-alloc image mount fusemount wait-devices fsck recovery-pass fs device subvolume reconcile scrub unlock set-passphrase remove-passphrase migrate migrate-superblock set-file-option reflink-option-propagate dump undump list list_journal kill_btree_node data-read unpoison completions version help" -f -a "recovery-pass" -d 'Manage recovery passes'
complete -c bcachefs -n "__fish_bcachefs_using_subcommand help; and not __fish_seen_subcommand_from format show-super recover-super set-fs-option reset-counters strip-alloc image mount fusemount wait-devices fsck recovery-pass fs device subvolume reconcile scrub unlock set-passphrase remove-passphrase migrate migrate-superblock set-file-option reflink-option-propagate dump undump list list_journal kill_btree_node data-read unpoison completions version help" -f -a "fs" -d 'Manage a running filesystem'
complete -c bcachefs -n "__fish_bcachefs_using_subcommand help; and not __fish_seen_subcommand_from format show-super recover-super set-fs-option reset-counters strip-alloc image mount fusemount wait-devices fsck recovery-pass fs device subvolume reconcile scrub unlock set-passphrase remove-passphrase migrate migrate-superblock set-file-option reflink-option-propagate dump undump list list_journal kill_btree_node data-read unpoison completions version help" -f -a "device" -d 'Manage devices within a filesystem'
complete -c bcachefs -n "__fish_bcachefs_using_subcommand help; and not __fish_seen_subcommand_from format show-super recover-super set-fs-option reset-counters strip-alloc image mount fusemount wait-devices fsck recovery-pass fs device subvolume reconcile scrub unlock set-passphrase remove-passphrase migrate migrate-superblock set-file-option reflink-option-propagate dump undump list list_journal kill_btree_node data-read unpoison completions version help" -f -a "subvolume" -d 'Manage subvolumes and snapshots'
complete -c bcachefs -n "__fish_bcachefs_using_subcommand help; and not __fish_seen_subcommand_from format show-super recover-super set-fs-option reset-counters strip-alloc image mount fusemount wait-devices fsck recovery-pass fs device subvolume reconcile scrub unlock set-passphrase remove-passphrase migrate migrate-superblock set-file-option reflink-option-propagate dump undump list list_journal kill_btree_node data-read unpoison completions version help" -f -a "reconcile" -d 'Reconcile filesystem data'
complete -c bcachefs -n "__fish_bcachefs_using_subcommand help; and not __fish_seen_subcommand_from format show-super recover-super set-fs-option reset-counters strip-alloc image mount fusemount wait-devices fsck recovery-pass fs device subvolume reconcile scrub unlock set-passphrase remove-passphrase migrate migrate-superblock set-file-option reflink-option-propagate dump undump list list_journal kill_btree_node data-read unpoison completions version help" -f -a "scrub" -d 'Verify data checksums'
complete -c bcachefs -n "__fish_bcachefs_using_subcommand help; and not __fish_seen_subcommand_from format show-super recover-super set-fs-option reset-counters strip-alloc image mount fusemount wait-devices fsck recovery-pass fs device subvolume reconcile scrub unlock set-passphrase remove-passphrase migrate migrate-superblock set-file-option reflink-option-propagate dump undump list list_journal kill_btree_node data-read unpoison completions version help" -f -a "unlock" -d 'Unlock an encrypted filesystem'
complete -c bcachefs -n "__fish_bcachefs_using_subcommand help; and not __fish_seen_subcommand_from format show-super recover-super set-fs-option reset-counters strip-alloc image mount fusemount wait-devices fsck recovery-pass fs device subvolume reconcile scrub unlock set-passphrase remove-passphrase migrate migrate-superblock set-file-option reflink-option-propagate dump undump list list_journal kill_btree_node data-read unpoison completions version help" -f -a "set-passphrase" -d 'Set or change passphrase'
complete -c bcachefs -n "__fish_bcachefs_using_subcommand help; and not __fish_seen_subcommand_from format show-super recover-super set-fs-option reset-counters strip-alloc image mount fusemount wait-devices fsck recovery-pass fs device subvolume reconcile scrub unlock set-passphrase remove-passphrase migrate migrate-superblock set-file-option reflink-option-propagate dump undump list list_journal kill_btree_node data-read unpoison completions version help" -f -a "remove-passphrase" -d 'Remove passphrase'
complete -c bcachefs -n "__fish_bcachefs_using_subcommand help; and not __fish_seen_subcommand_from format show-super recover-super set-fs-option reset-counters strip-alloc image mount fusemount wait-devices fsck recovery-pass fs device subvolume reconcile scrub unlock set-passphrase remove-passphrase migrate migrate-superblock set-file-option reflink-option-propagate dump undump list list_journal kill_btree_node data-read unpoison completions version help" -f -a "migrate" -d 'Migrate existing filesystem to bcachefs'
complete -c bcachefs -n "__fish_bcachefs_using_subcommand help; and not __fish_seen_subcommand_from format show-super recover-super set-fs-option reset-counters strip-alloc image mount fusemount wait-devices fsck recovery-pass fs device subvolume reconcile scrub unlock set-passphrase remove-passphrase migrate migrate-superblock set-file-option reflink-option-propagate dump undump list list_journal kill_btree_node data-read unpoison completions version help" -f -a "migrate-superblock" -d 'Move superblock to standard location'
complete -c bcachefs -n "__fish_bcachefs_using_subcommand help; and not __fish_seen_subcommand_from format show-super recover-super set-fs-option reset-counters strip-alloc image mount fusemount wait-devices fsck recovery-pass fs device subvolume reconcile scrub unlock set-passphrase remove-passphrase migrate migrate-superblock set-file-option reflink-option-propagate dump undump list list_journal kill_btree_node data-read unpoison completions version help" -f -a "set-file-option" -d 'Set file-level options'
complete -c bcachefs -n "__fish_bcachefs_using_subcommand help; and not __fish_seen_subcommand_from format show-super recover-super set-fs-option reset-counters strip-alloc image mount fusemount wait-devices fsck recovery-pass fs device subvolume reconcile scrub unlock set-passphrase remove-passphrase migrate migrate-superblock set-file-option reflink-option-propagate dump undump list list_journal kill_btree_node data-read unpoison completions version help" -f -a "reflink-option-propagate" -d 'Propagate options to reflinked files'
complete -c bcachefs -n "__fish_bcachefs_using_subcommand help; and not __fish_seen_subcommand_from format show-super recover-super set-fs-option reset-counters strip-alloc image mount fusemount wait-devices fsck recovery-pass fs device subvolume reconcile scrub unlock set-passphrase remove-passphrase migrate migrate-superblock set-file-option reflink-option-propagate dump undump list list_journal kill_btree_node data-read unpoison completions version help" -f -a "dump" -d 'Dump filesystem metadata'
complete -c bcachefs -n "__fish_bcachefs_using_subcommand help; and not __fish_seen_subcommand_from format show-super recover-super set-fs-option reset-counters strip-alloc image mount fusemount wait-devices fsck recovery-pass fs device subvolume reconcile scrub unlock set-passphrase remove-passphrase migrate migrate-superblock set-file-option reflink-option-propagate dump undump list list_journal kill_btree_node data-read unpoison completions version help" -f -a "undump" -d 'Restore dumped metadata'
complete -c bcachefs -n "__fish_bcachefs_using_subcommand help; and not __fish_seen_subcommand_from format show-super recover-super set-fs-option reset-counters strip-alloc image mount fusemount wait-devices fsck recovery-pass fs device subvolume reconcile scrub unlock set-passphrase remove-passphrase migrate migrate-superblock set-file-option reflink-option-propagate dump undump list list_journal kill_btree_node data-read unpoison completions version help" -f -a "list" -d 'List filesystem metadata'
complete -c bcachefs -n "__fish_bcachefs_using_subcommand help; and not __fish_seen_subcommand_from format show-super recover-super set-fs-option reset-counters strip-alloc image mount fusemount wait-devices fsck recovery-pass fs device subvolume reconcile scrub unlock set-passphrase remove-passphrase migrate migrate-superblock set-file-option reflink-option-propagate dump undump list list_journal kill_btree_node data-read unpoison completions version help" -f -a "list_journal" -d 'List journal entries'
complete -c bcachefs -n "__fish_bcachefs_using_subcommand help; and not __fish_seen_subcommand_from format show-super recover-super set-fs-option reset-counters strip-alloc image mount fusemount wait-devices fsck recovery-pass fs device subvolume reconcile scrub unlock set-passphrase remove-passphrase migrate migrate-superblock set-file-option reflink-option-propagate dump undump list list_journal kill_btree_node data-read unpoison completions version help" -f -a "kill_btree_node" -d 'Remove a btree node'
complete -c bcachefs -n "__fish_bcachefs_using_subcommand help; and not __fish_seen_subcommand_from format show-super recover-super set-fs-option reset-counters strip-alloc image mount fusemount wait-devices fsck recovery-pass fs device subvolume reconcile scrub unlock set-passphrase remove-passphrase migrate migrate-superblock set-file-option reflink-option-propagate dump undump list list_journal kill_btree_node data-read unpoison completions version help" -f -a "data-read" -d 'Read data with extended error info'
complete -c bcachefs -n "__fish_bcachefs_using_subcommand help; and not __fish_seen_subcommand_from format show-super recover-super set-fs-option reset-counters strip-alloc image mount fusemount wait-devices fsck recovery-pass fs device subvolume reconcile scrub unlock set-passphrase remove-passphrase migrate migrate-superblock set-file-option reflink-option-propagate dump undump list list_journal kill_btree_node data-read unpoison completions version help" -f -a "unpoison" -d 'Clear poison flags on file extents'
complete -c bcachefs -n "__fish_bcachefs_using_subcommand help; and not __fish_seen_subcommand_from format show-super recover-super set-fs-option reset-counters strip-alloc image mount fusemount wait-devices fsck recovery-pass fs device subvolume reconcile scrub unlock set-passphrase remove-passphrase migrate migrate-superblock set-file-option reflink-option-propagate dump undump list list_journal kill_btree_node data-read unpoison completions version help" -f -a "completions" -d 'Generate shell completions'
complete -c bcachefs -n "__fish_bcachefs_using_subcommand help; and not __fish_seen_subcommand_from format show-super recover-super set-fs-option reset-counters strip-alloc image mount fusemount wait-devices fsck recovery-pass fs device subvolume reconcile scrub unlock set-passphrase remove-passphrase migrate migrate-superblock set-file-option reflink-option-propagate dump undump list list_journal kill_btree_node data-read unpoison completions version help" -f -a "version" -d 'Display version'
complete -c bcachefs -n "__fish_bcachefs_using_subcommand help; and not __fish_seen_subcommand_from format show-super recover-super set-fs-option reset-counters strip-alloc image mount fusemount wait-devices fsck recovery-pass fs device subvolume reconcile scrub unlock set-passphrase remove-passphrase migrate migrate-superblock set-file-option reflink-option-propagate dump undump list list_journal kill_btree_node data-read unpoison completions version help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c bcachefs -n "__fish_bcachefs_using_subcommand help; and __fish_seen_subcommand_from image" -f -a "create" -d 'Create a filesystem image'
complete -c bcachefs -n "__fish_bcachefs_using_subcommand help; and __fish_seen_subcommand_from image" -f -a "update" -d 'Update a filesystem image'
complete -c bcachefs -n "__fish_bcachefs_using_subcommand help; and __fish_seen_subcommand_from fs" -f -a "usage" -d 'Show filesystem disk usage'
complete -c bcachefs -n "__fish_bcachefs_using_subcommand help; and __fish_seen_subcommand_from fs" -f -a "top" -d 'Show live performance counters'
complete -c bcachefs -n "__fish_bcachefs_using_subcommand help; and __fish_seen_subcommand_from fs" -f -a "timestats" -d 'Show operation latency statistics'
complete -c bcachefs -n "__fish_bcachefs_using_subcommand help; and __fish_seen_subcommand_from device" -f -a "add" -d 'Add a device to a filesystem'
complete -c bcachefs -n "__fish_bcachefs_using_subcommand help; and __fish_seen_subcommand_from device" -f -a "online" -d 'Bring a device online'
complete -c bcachefs -n "__fish_bcachefs_using_subcommand help; and __fish_seen_subcommand_from device" -f -a "offline" -d 'Take a device offline'
complete -c bcachefs -n "__fish_bcachefs_using_subcommand help; and __fish_seen_subcommand_from device" -f -a "remove" -d 'Remove a device'
complete -c bcachefs -n "__fish_bcachefs_using_subcommand help; and __fish_seen_subcommand_from device" -f -a "evacuate" -d 'Evacuate data from a device'
complete -c bcachefs -n "__fish_bcachefs_using_subcommand help; and __fish_seen_subcommand_from device" -f -a "set-state" -d 'Set device state'
complete -c bcachefs -n "__fish_bcachefs_using_subcommand help; and __fish_seen_subcommand_from device" -f -a "resize" -d 'Resize filesystem on a device'
complete -c bcachefs -n "__fish_bcachefs_using_subcommand help; and __fish_seen_subcommand_from device" -f -a "resize-journal" -d 'Resize journal on a device'
complete -c bcachefs -n "__fish_bcachefs_using_subcommand help; and __fish_seen_subcommand_from subvolume" -f -a "create" -d 'Create a new subvolume'
complete -c bcachefs -n "__fish_bcachefs_using_subcommand help; and __fish_seen_subcommand_from subvolume" -f -a "delete" -d 'Delete an existing subvolume'
complete -c bcachefs -n "__fish_bcachefs_using_subcommand help; and __fish_seen_subcommand_from subvolume" -f -a "snapshot" -d 'Create a snapshot of a subvolume'
complete -c bcachefs -n "__fish_bcachefs_using_subcommand help; and __fish_seen_subcommand_from subvolume" -f -a "list" -d 'List subvolumes'
complete -c bcachefs -n "__fish_bcachefs_using_subcommand help; and __fish_seen_subcommand_from subvolume" -f -a "list-snapshots" -d 'List snapshots and their disk usage'
complete -c bcachefs -n "__fish_bcachefs_using_subcommand help; and __fish_seen_subcommand_from reconcile" -f -a "status" -d 'Show reconcile status'
complete -c bcachefs -n "__fish_bcachefs_using_subcommand help; and __fish_seen_subcommand_from reconcile" -f -a "wait" -d 'Wait for reconcile to complete'
